#include <owl\applicat.h>
#include <owl\framewin.h>
#include <owl\editfile.h>
#include <owl\listbox.h>
#pragma hdrstop
#include "splitwin.h"
#include "splitapp.rh"

class Win2 : public TSplitWindow {
	public:
		Win2(TWindow* parent)
			: TSplitWindow(parent, "", new TListBox(0,0,0,0,0,0),
				new TListBox(0,0,0,0,0,0), 50, FALSE) {};
		void SetupWindow();
};

void
Win2::SetupWindow()
{
	TListBox* box1 = dynamic_cast<TListBox*>(GetLeftChild());
	TListBox* box2 = dynamic_cast<TListBox*>(GetRightChild());
	box1->Attr.Style &= ~LBS_SORT;
	box1->Attr.Style |= LBS_NOINTEGRALHEIGHT;
	box2->Attr.Style |= LBS_NOINTEGRALHEIGHT;
	TSplitWindow::SetupWindow();
	box1->AddString("This is a test");
	box1->AddString("To show that");
	box1->AddString("You can easily");
	box1->AddString("Add a list box");
	box1->AddString("As one of the");
	box1->AddString("TSplitWindow children");
	box1->AddString("This also demonstrates");
	box1->AddString("That you can use");
	box1->AddString("A TSplitWindow as a");
	box1->AddString("Child window of another");
	box1->AddString("TSplitWindow object");
	box1->AddString("The window below this one");
	box1->AddString("Is also a list box...");
	box2->DirectoryList(DDL_READONLY, "*.*");
}

class TMyWindow : public TSplitWindow {
	public:
		TMyWindow(TWindow* parent, const char far* title,
				TWindow* child1, TWindow* child2, int child1Size = 50,
				BOOL isVert = TRUE, bool isfixed = false, TModule* module = 0)
			: TSplitWindow(parent, title, child1, child2, child1Size, isVert, isfixed, module)
		{
			enableChange = TRUE;
		}
		~TMyWindow() {};
		void SetupWindow();
	protected:
		void CmSwitch();
		void CmChangeFocus();
		void CmToggleSizing();
		void CmNewEditFile();
		void CmNewSplitWin();
		void CmSetText();
		void CmSetTextEnable(TCommandEnabler&);
		void CmAbout();
	private:
		BOOL enableChange;

		DECLARE_RESPONSE_TABLE(TMyWindow);
};

DEFINE_RESPONSE_TABLE1(TMyWindow, TSplitWindow)
	EV_COMMAND(CM_SWITCH, CmSwitch),
	EV_COMMAND(CM_CHANGE_FOCUS, CmChangeFocus),
	EV_COMMAND(CM_TOGGLESIZING, CmToggleSizing),
	EV_COMMAND(CM_NEWEDITFILE, CmNewEditFile),
  EV_COMMAND(CM_NEWSPLITWIN, CmNewSplitWin),
	EV_COMMAND(CM_SETTEXT, CmSetText),
	EV_COMMAND_ENABLE(CM_SETTEXT, CmSetTextEnable),
	EV_COMMAND(CM_ABOUT, CmAbout),
END_RESPONSE_TABLE;

void TMyWindow::SetupWindow()
{
	TSplitWindow::SetupWindow();
	TEdit* edit = dynamic_cast<TEdit*>(GetRightChild());
	edit->SetText("This is an edit control . . .");
	//enableChange = true;
}

void TMyWindow::CmSwitch()
{
	Switch();
}

void TMyWindow::CmChangeFocus()
{
	NextChild();
}

void TMyWindow::CmToggleSizing()
{
	static int sizing;
	sizing = abs(1 - sizing);
	EnableFixedSizing(sizing);
}

void TMyWindow::CmSetText()
{
	TEdit* edit = dynamic_cast<TEdit*>(GetRightChild());
	edit->SetText("The text is now changed...");
}

void TMyWindow::CmSetTextEnable(TCommandEnabler& ce)
{
	ce.Enable(enableChange);
}

void TMyWindow::CmNewEditFile()
{
	enableChange = true;
	SetRightChild(new TEditFile(0,0,0,0,0,0,0,"splitwin.h"));
}

void TMyWindow::CmNewSplitWin()
{
	enableChange = false;
	SetRightChild(new Win2(0));
}

void TMyWindow::CmAbout()
{
	EnableFixedSizing(false);
	TDialog(this, IDD_ABOUT).Execute();
}

class TTestApp : public TApplication {
	public:
		TTestApp(const char far* title) : TApplication(title) {}

		void InitMainWindow()
		{
			TSplitWindow* client = new TMyWindow(0, 0,
				new TEditFile(0,0,0,0,0,0,0,"splitwin.txt"),
				new TEdit(0,0,0,0,0,0,0));
			SetMainWindow(new TFrameWindow(0, "Split Window Test Program", client));
			GetMainWindow()->AssignMenu(MENU_1);
		}
};

int OwlMain(int /*argc*/, char* /*argv*/ [])
{
	TTestApp app("Test App");
	int ret = app.Run();
	return ret;
}