//----------------------------------------------------------------------------
// TSplitWindow v. 1.02 - (C) Copyright 1995 by Kent Reisdorph
// #include "splitwin.h"
// Definition of class TSplitWindow, a class allow horizontal
// or vertical splitting and resizing of two windows.
//----------------------------------------------------------------------------

#ifndef __SPLITWIN_H
#define __SPLITWIN_H

#ifndef __OWL_LAYOUTWI_H
#include <owl\layoutwi.h>
#endif
#ifndef __OWL_GDIOBJEC_H
#include <owl\gdiobjec.h>
#endif
#ifndef __OWL_DC_H
#include <owl\dc.h>
#endif
#ifndef __OWL_LISTBOX_H
#include <owl\listbox.h>
#endif

#define LEFT_CHILD 1
#define RIGHT_CHILD 2

class TSplitWindow : public TLayoutWindow {
	public:
		TSplitWindow(TWindow* parent, const char far* title,
									TWindow* child1, TWindow* child2, int child1Size = 50,
									bool isVert = true, bool isfixed = false, TModule* module = 0);
		TSplitWindow(const TSplitWindow& sw);
		~TSplitWindow();
		TSplitWindow& operator = (const TSplitWindow& sw);
		int operator == (const TSplitWindow& sw) const;
		void Switch();
		TWindow* SetLeftChild(TWindow* client);
		TWindow* SetRightChild(TWindow* client);
		bool IsVertical();
		TWindow* GetLeftChild();
		TWindow* GetRightChild();
		int GetLeftChildSize();
		void NextChild(int child = 0);
		void EnableFixedSizing(bool enable = true);
		int minWndSize;

	protected:
		void SetupWindow();
		void EvLButtonDown(uint, TPoint&);
		void EvLButtonUp(uint, TPoint&);
		void EvMouseMove(uint, TPoint&);
		bool EvSetCursor(HWND, uint, uint);

	private:
		void LayoutVertical();
		void LayoutHorizontal();
		void SetNewPositions(TPoint& point);
		void DrawSizingBar(TPoint& point);
		
		bool isVertical;
		bool isFixedSize;
		TWindow* childLeft;
		TWindow* childRight;
		TPoint oldPoint;
		TPen* sizingPen;
		bool dragging;
		bool offScreen;
		int leftChildSize;
		int clientHeight;
		int clientWidth;
		char* arrowType;
		TWindowDC* dc;

	DECLARE_RESPONSE_TABLE(TSplitWindow);
};

inline bool TSplitWindow::IsVertical() {
	return isVertical;
}

inline TWindow* TSplitWindow::GetLeftChild() {
	return childLeft;
}

inline TWindow* TSplitWindow::GetRightChild() {
	return childRight;
}

inline int TSplitWindow::GetLeftChildSize() {
	return leftChildSize;
}

inline void TSplitWindow::EnableFixedSizing(bool enable) {
	isFixedSize = enable;
	if (isVertical) LayoutVertical();
  else LayoutHorizontal();
}

#endif

